==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/nb-NO/localizations.php <==
<?php

return [

    'select_language' => 'Velg et språk',
    'languages' => [
        'en-US'=> 'Engelsk, USA',
        'en-GB'=> 'Engelsk, Storbritannia',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikansk',
        'ar-SA'=> 'Arabisk',
        'bg-BG'=> 'Bulgarsk',
        'zh-CN'=> 'Forenklet kinesisk',
        'zh-TW'=> 'Tradisjonell kinesisk',
        'ca-ES' => 'Katalansk',
        'hr-HR'=> 'Kroatisk',
        'cs-CZ'=> 'Tsjekkisk',
        'da-DK'=> 'Dansk',
        'nl-NL'=> 'Nederlandsk',
        'en-ID'=> 'Engelsk, Indonesia',
        'et-EE'=> 'Estisk',
        'fil-PH'=> 'Filippinsk',
        'fi-FI'=> 'Finsk',
        'fr-FR'=> 'Fransk',
        'de-DE'=> 'Tysk',
        'de-if'=> 'Tysk (uformel)',
        'el-GR'=> 'Gresk',
        'he-IL'=> 'Hebraisk',
        'hu-HU'=> 'Ungarsk',
        'is-IS' => 'Islandsk',
        'id-ID'=> 'Indonesisk',
        'ga-IE'=> 'Irsk',
        'it-IT'=> 'Italiensk',
        'ja-JP'=> 'Japansk',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Koreansk',
        'lt-LT'=>'Litauisk',
        'lv-LV'=> 'Latvisk',
        'mk-MK'=> 'Makedonsk',
        'ms-MY'=> 'Malayisk',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongolsk',
        'no-NO'=> 'Norsk',
        'fa-IR'=> 'Persisk',
        'pl-PL'=> 'Polsk',
        'pt-PT'=> 'Portugisisk',
        'pt-BR'=> 'Portugisisk, Brasiliansk',
        'ro-RO'=> 'Rumensk',
        'ru-RU'=> 'Russisk',
        'sr-CS' => 'Serbisk (Latin)',
        'sk-SK'=> 'Slovakisk',
        'sl-SI'=> 'Slovensk',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Spansk',
        'es-CO'=> 'Spansk, Colombia',
        'es-MX'=> 'Spansk, Mexico',
        'es-VE'=> 'Spansk, Venezuela',
        'sv-SE'=> 'Svensk',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamilsk',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Tyrkisk',
        'uk-UA'=> 'Ukrainsk',
        'vi-VN'=> 'Vietnamesisk',
        'cy-GB'=> 'Walisisk',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Velg et land',
    
    'countries' => [
        'AC'=>'Ascension Island',
        'AD'=>'Andorra',
        'AE'=>'De forente arabiske emirater',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua og Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'De nederlandske Antillene',
        'AO'=>'Angola',
        'AQ'=>'Antarktis',
        'AR'=>'Argentina',
        'AS'=>'Amerikansk Samoa',
        'AT'=>'Østerrike',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Åland',
        'AZ'=>'Aserbajdsjan',
        'BA'=>'Bosnia-Hercegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgia',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brasil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet-øya',
        'BW'=>'Botswana',
        'BY'=>'Republikken Belarus',
        'BZ'=>'Belize',
        'CA'=>'Canada',
        'CC'=>'Kokosøyene (Keelingøyene)',
        'CD'=>'Den demokratiske republikken Kongo',
        'CF'=>'Den sentralafrikanske republikk',
        'CG'=>'Republikken Kongo',
        'CH'=>'Sveits',
        'CI'=>'Elfenbenskysten',
        'CK'=>'Cook-øyene',
        'CL'=>'Chile',
        'CM'=>'Kamerun',
        'CN'=>'Folkerepublikken Kina',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Kapp Verde',
        'CX'=>'Christmasøya',
        'CY'=>'Kypros',
        'CZ'=>'Tsjekkia',
        'DE'=>'Tyskland',
        'DJ'=>'Djibouti',
        'DK'=>'Danmark',
        'DM'=>'Dominica',
        'DO'=>'Den dominikanske republikk',
        'DZ'=>'Algerie',
        'EC'=>'Ecuador',
        'EE'=>'Estland',
        'EG'=>'Egypt',
        'ER'=>'Eritrea',
        'ES'=>'Spania',
        'ET'=>'Etiopia',
        'EU'=>'EU',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falklandsøyene (Malvinas)',
        'FM'=>'Mikronesia, De forente stater',
        'FO'=>'Færøyene',
        'FR'=>'Frankrike',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'Fransk Guyana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Grønland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Ekvatorial-Guinea',
        'GR'=>'Hellas',
        'GS'=>'Sør-Georgia og Sør-Sandwichøyene',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Heard og Mc Donald Øyene',
        'HN'=>'Honduras',
        'HR'=>'Kroatia (lokalt navn: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Ungarn',
        'ID'=>'Indonesia',
        'IE'=>'Irland',
        'IL'=>'Israel',
        'IM'=>'Isle of Man',
        'IN'=>'India',
        'IO'=>'Det britiske territoriet i Indiahavet',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Island',
        'IT'=>'Italia',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kirgisistan',
        'KH'=>'Kambodsja',
        'KI'=>'Kiribati',
        'KM'=>'Komorene',
        'KN'=>'Saint Kitts og Nevis',
        'KR'=>'Republikken Korea',
        'KW'=>'Kuwait',
        'KY'=>'Caymanøyene',
        'KZ'=>'Kasakhstan',
        'LA'=>'Laos',
        'LB'=>'Libanon',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Litauen',
        'LU'=>'Luxemburg',
        'LV'=>'Latvia',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Marokko',
        'MC'=>'Monaco',
        'MD'=>'Moldova',
        'ME'=>'Montenegro',
        'MG'=>'Madagaskar',
        'MH'=>'Marshalløyene',
        'MK'=>'Makedonia, den tidligere jugoslaviske republikken',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macao',
        'MP'=>'Nord-Marianene',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldivene',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mosambik',
        'NA'=>'Namibia',
        'NC'=>'Ny Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolkøyene',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederland',
        'NO'=>'Norge',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Fransk Polynesia',
        'PG'=>'Papua Ny-Guinea',
        'PH'=>'Filippinene',
        'PK'=>'Pakistan',
        'PL'=>'Polen',
        'PM'=>'St. Pierre og Miquelon',
        'PN'=>'Pitcairnøyene',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Réunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russland',
        'RW'=>'Rwanda',
        'SA'=>'Saudi-Arabia',
        'UK'=>'Storbritannia',
        'SB'=>'Salomonøyene',
        'SC'=>'Seychellene',
        'SS'=>'Sør-Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sverige',
        'SG'=>'Singapor',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard og Jan Mayen',
        'SK'=>'Slovakia',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome og Principe',
        'SU'=>'Sovjet',
        'SV'=>'El Salvador',
        'SY'=>'Syria',
        'SZ'=>'Swaziland',
        'TC'=>'Turks- og Caicosøyene',
        'TD'=>'Tsjad',
        'TF'=>'De franske sørterritorier',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tadsjikistan',
        'TK'=>'Tokelau',
        'TI'=>'Øst-Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'Øst Timor',
        'TR'=>'Tyrkia',
        'TT'=>'Trinidad og Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Storbritannia',
        'US'=>'USA',
        'UM'=>'USAs ytre småøyer',
        'UY'=>'Uruguay',
        'UZ'=>'Usbekistan',
        'VA'=>'Vatikanstaten',
        'VC'=>'Saint Vincent og Grenadinene',
        'VE'=>'Venezuela',
        'VG'=>'Jomfru øyene (Storbritannia)',
        'VI'=>'Jomfruøyene, (USA)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'WF'=>'Wallis- og Futunaøyene',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/nb-NO/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'Engelsk, USA',
        'en-GB'=> 'Engelsk, Storbritannia',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikansk',
        'ar-SA'=> 'Arabisk',
        'bg-BG'=> 'Bulgarsk',
        'zh-CN'=> 'Forenklet kinesisk',
        'zh-TW'=> 'Tradisjonell kinesisk',
        'ca-ES' => 'Katalansk',
        'hr-HR'=> 'Kroatisk',
        'cs-CZ'=> 'Tsjekkisk',
        'da-DK'=> 'Dansk',
        'nl-NL'=> 'Nederlandsk',
        'en-ID'=> 'Engelsk, Indonesia',
        'et-EE'=> 'Estisk',
        'fil-PH'=> 'Filippinsk',
        'fi-FI'=> 'Finsk',
        'fr-FR'=> 'Fransk',
        'de-DE'=> 'Tysk',
        'de-if'=> 'Tysk (uformel)',
        'el-GR'=> 'Gresk',
        'he-IL'=> 'Hebraisk',
        'hu-HU'=> 'Ungarsk',
        'is-IS' => 'Islandsk',
        'id-ID'=> 'Indonesisk',
        'ga-IE'=> 'Irsk',
        'it-IT'=> 'Italiensk',
        'ja-JP'=> 'Japansk',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Koreansk',
        'lt-LT'=>'Litauisk',
        'lv-LV'=> 'Latvisk',
        'mk-MK'=> 'Makedonsk',
        'ms-MY'=> 'Malayisk',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongolsk',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persisk',
        'pl-PL'=> 'Polsk',
        'pt-PT'=> 'Portugisisk',
        'pt-BR'=> 'Portugisisk, Brasiliansk',
        'ro-RO'=> 'Rumensk',
        'ru-RU'=> 'Russisk',
        'sr-CS' => 'Serbisk (Latin)',
        'sk-SK'=> 'Slovakisk',
        'sl-SI'=> 'Slovensk',
        'so-SO'=> 'Somali',
        'es-ES'=> 'Spansk',
        'es-CO'=> 'Spansk, Colombia',
        'es-MX'=> 'Spansk, Mexico',
        'es-VE'=> 'Spansk, Venezuela',
        'sv-SE'=> 'Svensk',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamilsk',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Tyrkisk',
        'uk-UA'=> 'Ukrainsk',
        'vi-VN'=> 'Vietnamesisk',
        'cy-GB'=> 'Walisisk',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'Ascension Island',
        'AD'=>'Andorra',
        'AE'=>'De forente arabiske emirater',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua og Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'De nederlandske Antillene',
        'AO'=>'Angola',
        'AQ'=>'Antarktis',
        'AR'=>'Argentina',
        'AS'=>'Amerikansk Samoa',
        'AT'=>'Østerrike',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Åland',
        'AZ'=>'Aserbajdsjan',
        'BA'=>'Bosnia-Hercegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgia',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brasil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet-øya',
        'BW'=>'Botswana',
        'BY'=>'Republikken Belarus',
        'BZ'=>'Belize',
        'CA'=>'Canada',
        'CC'=>'Kokosøyene (Keelingøyene)',
        'CD'=>'Den demokratiske republikken Kongo',
        'CF'=>'Den sentralafrikanske republikk',
        'CG'=>'Republikken Kongo',
        'CH'=>'Sveits',
        'CI'=>'Elfenbenskysten',
        'CK'=>'Cook-øyene',
        'CL'=>'Chile',
        'CM'=>'Kamerun',
        'CN'=>'Folkerepublikken Kina',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Kapp Verde',
        'CX'=>'Christmasøya',
        'CY'=>'Kypros',
        'CZ'=>'Tsjekkia',
        'DE'=>'Tyskland',
        'DJ'=>'Djibouti',
        'DK'=>'Danmark',
        'DM'=>'Dominica',
        'DO'=>'Den dominikanske republikk',
        'DZ'=>'Algerie',
        'EC'=>'Ecuador',
        'EE'=>'Estland',
        'EG'=>'Egypt',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Spania',
        'ET'=>'Etiopia',
        'EU'=>'EU',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falklandsøyene (Malvinas)',
        'FM'=>'Mikronesia, De forente stater',
        'FO'=>'Færøyene',
        'FR'=>'Frankrike',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'Fransk Guyana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Grønland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Ekvatorial-Guinea',
        'GR'=>'Hellas',
        'GS'=>'Sør-Georgia og Sør-Sandwichøyene',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Heard og Mc Donald Øyene',
        'HN'=>'Honduras',
        'HR'=>'Kroatia (lokalt navn: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Ungarn',
        'ID'=>'Indonesia',
        'IE'=>'Irland',
        'IL'=>'Israel',
        'IM'=>'Isle of Man',
        'IN'=>'India',
        'IO'=>'Det britiske territoriet i Indiahavet',
        'IQ'=>'Irak',
        'IR'=>'Iran',
        'IS'=>'Island',
        'IT'=>'Italia',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kirgisistan',
        'KH'=>'Kambodsja',
        'KI'=>'Kiribati',
        'KM'=>'Komorene',
        'KN'=>'Saint Kitts og Nevis',
        'KR'=>'Republikken Korea',
        'KW'=>'Kuwait',
        'KY'=>'Caymanøyene',
        'KZ'=>'Kasakhstan',
        'LA'=>'Laos',
        'LB'=>'Libanon',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Litauen',
        'LU'=>'Luxemburg',
        'LV'=>'Latvia',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Marokko',
        'MC'=>'Monaco',
        'MD'=>'Moldova',
        'ME'=>'Montenegro',
        'MG'=>'Madagaskar',
        'MH'=>'Marshalløyene',
        'MK'=>'Makedonia, den tidligere jugoslaviske republikken',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macao',
        'MP'=>'Nord-Marianene',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldivene',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mosambik',
        'NA'=>'Namibia',
        'NC'=>'Ny Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolkøyene',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Nederland',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norge',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Fransk Polynesia',
        'PG'=>'Papua Ny-Guinea',
        'PH'=>'Filippinene',
        'PK'=>'Pakistan',
        'PL'=>'Polen',
        'PM'=>'St. Pierre og Miquelon',
        'PN'=>'Pitcairnøyene',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestina',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Réunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russland',
        'RW'=>'Rwanda',
        'SA'=>'Saudi-Arabia',
        'GB-SCT'=>'Storbritannia',
        'SB'=>'Salomonøyene',
        'SC'=>'Seychellene',
        'SS'=>'Sør-Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sverige',
        'SG'=>'Singapor',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard og Jan Mayen',
        'SK'=>'Slovakia',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome og Principe',
        'SU'=>'Sovjet',
        'SV'=>'El Salvador',
        'SY'=>'Syria',
        'SZ'=>'Swaziland',
        'TC'=>'Turks- og Caicosøyene',
        'TD'=>'Tsjad',
        'TF'=>'De franske sørterritorier',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tadsjikistan',
        'TK'=>'Tokelau',
        'TI'=>'Øst-Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'Øst Timor',
        'TR'=>'Tyrkia',
        'TT'=>'Trinidad og Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Storbritannia',
        'US'=>'USA',
        'UM'=>'USAs ytre småøyer',
        'UY'=>'Uruguay',
        'UZ'=>'Usbekistan',
        'VA'=>'Vatikanstaten',
        'VC'=>'Saint Vincent og Grenadinene',
        'VE'=>'Venezuela',
        'VG'=>'Jomfru øyene (Storbritannia)',
        'VI'=>'Jomfruøyene, (USA)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis- og Futunaøyene',
        'WS'=>'Samoa',
        'YE'=>'Jemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
